==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/cms_pages_controller.rb <==
# -*- coding: utf-8 -*-
require 'fileutils'
class CmsPagesController < ApplicationController
  class_desc :display_name => 'ページ管理'

  protect_from_forgery :except => [:realtime_preview]
  before_filter :find_cms_project, :except => [:tag_reference]

  private
  def find_cms_project
    session[:project_id] ||= params[:project_id]
    if params[:project_id] && session[:project_id] != params[:project_id]
      session[:project_id] = params[:project_id]
    end
    @cms_project = CmsProject.find(session[:project_id])
  end

  public
  #
  def index
    session[:cms_pages_new] = nil

    @condition = prepare_session_condition do |condition|
      condition || CmsPage::SearchCondition.new(params[:condition])
    end
    @condition.cms_project_id = @cms_project.id
    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    query, @delete_ids = @condition.create_query
    # paginate_by_sqlで取得します
    @cms_pages = CmsPage.paginate_by_sql(query, :order => 'id', :page => params[:page], :per_page => per_page)
  end

  # GET /cms_pages/1
  # GET /cms_pages/1.xml
  def show
    session[:cms_pages_new] = nil

    @cms_page = CmsPage.find(params[:id])
    @cms_page.binds.each do |bind|
      bind.set_bind_name  if bind.cms_template_id
    end
    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @cms_page }
    end
  end

  desc :auth_as => :index
  #
  # 編集中プレビュー
  #
  def realtime_preview
    generated_erb = CmsXml.generate_erb(params[:user_content])
    render(:inline => generated_erb, :layout => 'cms_realtime_preview')
  end

  desc :auth_as => :create
  # GET /cms_pages/new
  # GET /cms_pages/new.xml
  def setup
    if session[:cms_pages_new]
      @cms_page = session[:cms_pages_new]
    else
      @cms_page = CmsPage.new
      I18n.supported_locales.each do |locale|
        @cms_page.titles << CmsPageTitle.new(:locale => locale.to_s)
      end
    end

    @page_options = CmsPage.find(:all, :include => [:titles], :conditions => ['cms_page_titles.locale = ?', "ja"]).
      map{|page| [page.titles[0].name, page.id] }
  end

  # GET /cms_pages/new
  # GET /cms_pages/new.xml
  def new
    if params[:source_id]
      # /cms_pages/indexからの遷移。PJ編集対象以外のページを編集（コピーして登録）する場合。ページ、バインド、ページタイトルをコピー
      org_page = CmsPage.find(params[:source_id])
      @cms_page = org_page.clone(:include => [{:binds => {:items => :contents}}, :titles])
    else
      if params[:cms_page][:org_id].blank?
        # /cms_pages/setupからの遷移。コピーしない場合。
        @cms_page = CmsPage.new(params[:cms_page])
        CmsBind.position_ids.each do |position|
          @cms_page.binds << CmsBind.new(:position => position, :items => [])
        end
      else
        # /cms_pages/setupからの遷移。コピーする場合。ページとバインドをコピー
        org_page = CmsPage.find(params[:cms_page][:org_id])
        @cms_page = org_page.clone(:include => {:binds => {:items => :contents}})
        @cms_page.action = ''
        @cms_page.controller = 'cms'
        @cms_page.cms_project_id = @cms_project.id
      end
      I18n.supported_locales.each do |locale|
        @cms_page.titles << CmsPageTitle.new(params[:cms_page][:titles_attributes][locale.to_s.intern])
      end
      unless @cms_page.validate_for_setup?
        @page_options = CmsPage.find(:all, :include => [:titles], :conditions => ['cms_page_titles.locale = ?', "ja"]).
          map{|page| [page.titles[0].name, page.id] }
        render :action => 'setup'
        return
      end
    end

    session[:cms_pages_new] = @cms_page

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @cms_page }
    end
  end

  public

  desc :auth_as => :update
  def new_bind
    unless params[:template_id].blank?
    template = CmsTemplate.find(params[:template_id], :include => :contents)
    @bind = CmsBind.new
    template.bind_items.each do |new_item|
      new_bind_item = CmsBindItem.new(new_item)
      I18n.supported_locales.each do |locale|
        new_bind_item.contents << CmsBindContent.new(:locale => locale.to_s)
      end
      @bind.items << new_bind_item
    end

    responseText = ''
    @bind.items.each_with_index do |item, index|
      responseText << %{
      <% fields_for("cms_page[binds_attributes][#{params[:position]}][items_attributes][#{index}]", @bind.items[#{index}]) do |f_item| %>
      <table id="new_bind" style="">
       <%= render(:partial => 'bind', :locals => {:f => f_item, :position => #{params[:position]}, :item => @bind.items[#{index}], :index => #{index}}) %>
      </table>
      <% end %>
      }.split(/$/).map(&:strip).join("\n")
    end

    responseText << %{
      <script type="text/javascript">
      //<![CDATA[
        <%= "var dest_table = $('template_table#{params[:position]}');"%>
        $$("#new_bind tr").each(function(row){
          row.parentNode.removeChild(row);
          dest_table.appendChild(row);
        });
      //]]>
      </script>
      }.split(/$/).map(&:strip).join("\n")
    end
    render(:inline => responseText || '')
  end

  # GET /cms_pages/1/edit
  def edit
    @cms_page = CmsPage.find(params[:id])
    @cms_page.binds.each do |bind|
      bind.set_bind_name  if bind.cms_template_id
      bind.items.each do |item|
        item.input_type = item.code == 'content' ?  'tab' : 'select'
      end
    end
  end

  # POST /cms_pages
  # POST /cms_pages.xml
  def create
    if params[:source_id]
      # PJ公開時に削除する場合。コントローラ名とアクション名をコピーして公開時に削除フラグをtrueにセット
      src_page = CmsPage.find(params[:source_id])
      cms_page = src_page.clone(:include => [:titles, {:binds => {:items => :contents} }])
      cms_page.cms_project_id = @cms_project.id
      cms_page.delete_at_publish = true
      cms_page.save!
      redirect_to :action => "index"
    else
      @cms_page = CmsPage.new(params[:cms_page].merge(:cms_project_id => @cms_project.id))
      @cms_page.set_values_for_create
      if @cms_page.save
        redirect_to(@cms_page)
      else
        render :action => "new"
      end
    end
  end

  # PUT /cms_pages/1
  # PUT /cms_pages/1.xml
  def update
    @cms_page = CmsPage.find(params[:id])
    @cms_page.attributes = params[:cms_page]

    CmsPage.transaction do
      @cms_page.save!
      @cms_page.titles.each do |title|
        title.attributes = @cms_page.titles_attributes[title.locale.intern ]
        title.save!
      end

      @cms_page.binds.each do|bind|
        bind.items.each do |item|
          item.contents.each do |content|
            content.destroy
          end if item.contents
          item.destroy
        end if bind.items
        bind.destroy
      end
      @cms_page.binds.clear
      @cms_page.binds_attributes.each_value do |binds_attribute|
        bind = CmsBind.new(binds_attribute)
        bind.items_attributes.each_value do |items_attribute|
          item = CmsBindItem.new(items_attribute)
          item.contents_attributes.each_value do |contents_attribute|
            content = CmsBindContent.new(contents_attribute)
            content.descriptions = '' if item.input_type == CmsBindItem.input_type_id_by_key(:select)
            item.contents << CmsBindContent.new(contents_attribute)
          end if item.contents_attributes
          bind.items << item
        end if bind.items_attributes
        @cms_page.binds << bind
      end
    end
    redirect_to(:action => 'show', :id => @cms_page.id)
  rescue
    render :action => "edit"
  end

  # DELETE /cms_pages/1
  # DELETE /cms_pages/1.xml
  def destroy
    @cms_page = CmsPage.find(params[:id])
    CmsPage.transaction do
      @cms_page.destroy_with_titles_and_items

      respond_to do |format|
        format.html { redirect_to(cms_pages_url) }
        format.xml  { head :ok }
      end
    end
  end

  desc :auth_as => :destroy
  # DELETE /cms_pages/undo_destroy/1
  # DELETE /cms_pages/undo_destroy/1.xml
  def undo_destroy
    src_page = CmsPage.find(params[:id])
    cms_page = CmsPage.find(:first,
      :conditions => ["cms_project_id = ? and controller = ? and action = ? and delete_at_publish = ?", 
        @cms_project.id, src_page.controller, src_page.action, true])
    page_id = cms_page.id
    @cms_page = CmsPage.find(page_id)
    CmsPage.transaction do
      @cms_page.destroy_with_titles_and_items

      respond_to do |format|
        format.html { redirect_to(cms_pages_url) }
        format.xml  { head :ok }
      end
    end
  end

  desc :auth_as => :index
  def preview
    @cms_page = CmsPage.find(params[:id])
    @cms_page.deploy_to_preview(params[:locale])
    @cms_page.copy_public_files_for_preview
      
    # デフォルトテンプレートのファイルを作成
    CmsTemplate.primary_default_templates.each do |position, template|
      template.overwrite(:preview) unless template.nil?
    end
    redirect_to :controller => 'cms', :action => 'show', :id => @cms_page.id, :locale => params[:locale]
  end

  desc :auth_as => :index
  def tag_reference
    render :layout => false
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/cms_pages_controller.rb <==
# -*- coding: utf-8 -*-
require 'fileutils'
class CmsPagesController < ApplicationController
  class_desc :display_name => 'プロジェクト管理->ページ管理'

  protect_from_forgery :except => [:realtime_preview]
  before_filter :find_cms_project

  private
  def find_cms_project
    session[:project_id] ||= params[:project_id]
    if params[:project_id] && session[:project_id] != params[:project_id]
      session[:project_id] = params[:project_id]
    end
    @cms_project = CmsProject.find(session[:project_id])
  end

  public
  #
  def index
    session[:cms_pages_new] = nil

    @condition = prepare_session_condition do |condition|
      condition || CmsPage::SearchCondition.new(params[:condition])
    end
    @condition.cms_project_id = @cms_project.id
    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    query, @delete_ids = @condition.create_query
    # paginate_by_sqlで取得します
    @cms_pages = CmsPage.paginate_by_sql(query, :order => 'id', :page => params[:page], :per_page => per_page)
  end

  # GET /cms_pages/1
  # GET /cms_pages/1.xml
  def show
    session[:cms_pages_new] = nil

    @cms_page = CmsPage.find(params[:id])
    @cms_page.binds.each do |bind|
      bind.set_bind_name  if bind.cms_template_id
    end
    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @cms_page }
    end
  end

  desc :auth_as => :index
  #
  # 編集中プレビュー
  #
  def realtime_preview
    generated_erb = CmsXml.generate_erb(params[:user_content])
    render(:inline => generated_erb, :layout => 'cms_realtime_preview')
  end

  desc :auth_as => :create
  # GET /cms_pages/new
  # GET /cms_pages/new.xml
  def setup
    if session[:cms_pages_new]
      @cms_page = session[:cms_pages_new]
    else
      terminal_key = :pc
      terminal_key = :mobile if params[:terminal] == CmsTemplate.terminal_id_by_key(:mobile)
      @cms_page = CmsPage.new(:terminal_key => terminal_key)
      if terminal_key == :pc
        I18n.supported_locales.each do |locale|
          @cms_page.titles << CmsPageTitle.new(:locale => locale.to_s)
        end
      else
        CmsTemplateContent.carrier_ids.each do |locale|
          @cms_page.titles << CmsPageTitle.new(:locale => locale.to_s)
        end
      end
    end

    @cms_page.terminal_key == :pc ? locale = 'ja' : locale = 'docomo'
    @page_options = CmsPage.find(:all, :include => [:titles], :conditions => ['cms_page_titles.locale = ?', locale]).
      map{|page| [page.titles[0].name, page.id] }
  end

  # GET /cms_pages/new
  # GET /cms_pages/new.xml
  def new
    if params[:source_id]
      # /cms_pages/indexからの遷移。PJ編集対象以外のページを編集（コピーして登録）する場合。ページ、バインド、ページタイトルをコピー
      org_page = CmsPage.find(params[:source_id])
      @cms_page = org_page.clone(:include => [{:binds => {:items => :contents}}, :titles])
      @cms_page.binds.each do |bind|
        bind.set_bind_name  if bind.cms_template_id
        bind.items.each do |item|
          item.input_type = item.code == 'content' ?  'tab' : 'select'
        end
      end
    else
      if params[:cms_page][:org_id].blank?
        # /cms_pages/setupからの遷移。コピーしない場合。
        @cms_page = CmsPage.new(params[:cms_page])
        position_ids = params[:cms_page][:terminal] == CmsTemplate.terminal_id_by_key(:pc) ? CmsBind.position_ids : CmsBind.position_mobile_ids
        position_ids.each do |position|
          @cms_page.binds << CmsBind.new(:position => position, :items => [])
        end
      else
        # /cms_pages/setupからの遷移。コピーする場合。ページとバインドをコピー
        org_page = CmsPage.find(params[:cms_page][:org_id])
        @cms_page = org_page.clone(:include => {:binds => {:items => :contents}})
        @cms_page.action = ''
        @cms_page.controller = 'cms'
        @cms_page.cms_project_id = @cms_project.id
      end
      if params[:cms_page][:terminal] == CmsTemplate.terminal_id_by_key(:pc)
        I18n.supported_locales.each do |locale|
          @cms_page.titles << CmsPageTitle.new(params[:cms_page][:titles_attributes][locale.to_s.intern])
        end
      else
        CmsTemplateContent.carrier_ids.each do |locale|
          @cms_page.titles << CmsPageTitle.new(params[:cms_page][:titles_attributes][locale.to_s.intern])
        end
      end
      unless @cms_page.validate_for_setup?
        @cms_page.terminal_key == :pc ? locale = 'ja' : locale = 'docomo'
        @page_options = CmsPage.find(:all, :include => [:titles], :conditions => ['cms_page_titles.locale = ?', locale]).
          map{|page| [page.titles[0].name, page.id] }
        render :action => 'setup'
        return
      end
    end

    session[:cms_pages_new] = @cms_page

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @cms_page }
    end
  end

  public

  desc :auth_as => :update
  def new_bind
    unless params[:template_id].blank?
      template = CmsTemplate.find(params[:template_id], :include => :contents)
      @bind = CmsBind.new
      template.bind_items.each do |new_item|
        new_bind_item = CmsBindItem.new(new_item)
        I18n.supported_locales.each do |locale|
          new_bind_item.contents << CmsBindContent.new(:locale => locale.to_s)
        end
        @bind.items << new_bind_item
      end

      responseText = ''
      @bind.items.each_with_index do |item, index|
        responseText << %{
          <% fields_for("cms_page[binds_attributes][#{params[:position]}][items_attributes][#{index}]", @bind.items[#{index}]) do |f_item| %>
            <table id="new_bind" class="standard_table">
              <%= render(:partial => 'bind', :locals => {:f => f_item, :position => #{params[:position]}, :item => @bind.items[#{index}], :index => #{index}}) %>
            </table>
          <% end %>
        }.split(/$/).map(&:strip).join("\n")
      end
    end
    render(:inline => responseText || '')
  end

  # GET /cms_pages/1/edit
  def edit
    @cms_page = CmsPage.find(params[:id])
    @cms_page.binds.each do |bind|
      bind.set_bind_name  if bind.cms_template_id
      bind.items.each do |item|
        item.input_type = item.code == 'content' ?  'tab' : 'select'
      end
    end
  end

  # POST /cms_pages
  # POST /cms_pages.xml
  def create
    if params[:source_id]
      # PJ公開時に削除する場合。コントローラ名とアクション名をコピーして公開時に削除フラグをtrueにセット
      src_page = CmsPage.find(params[:source_id])
      cms_page = src_page.clone(:include => [:titles, {:binds => {:items => :contents} }])
      cms_page.cms_project_id = @cms_project.id
      cms_page.delete_at_publish = true
      cms_page.save!
      redirect_to :action => "index"
    else
      copied_cms_project_id = params[:cms_page][:cms_project_id]
      @cms_page = CmsPage.new(params[:cms_page].merge(:cms_project_id => @cms_project.id))
      @cms_page.set_values_for_create
      if @cms_page.save
        redirect_to(@cms_page)
      else
        @cms_page.cms_project_id = copied_cms_project_id
        render :action => "new"
      end
    end
  end

  # PUT /cms_pages/1
  # PUT /cms_pages/1.xml
  def update
    @cms_page = CmsPage.find(params[:id])
    @cms_page.attributes = params[:cms_page]

    # バリデーションチェック
    unless @cms_page.valid?
      @cms_page.binds.each_with_index do |bind, index|
        bind.attributes = params[:cms_page][:binds_attributes][index.to_s]
      end
      return render :action => "edit"
    end

    CmsPage.transaction do
      @cms_page.save!
      @cms_page.titles.each do |title|
        title.attributes = @cms_page.titles_attributes[title.locale.intern ]
        title.save!
      end

      @cms_page.binds.each do|bind|
        bind.items.each do |item|
          item.contents.each do |content|
            content.destroy
          end if item.contents
          item.destroy
        end if bind.items
        bind.destroy
      end
      @cms_page.binds.clear
      @cms_page.binds_attributes.each_value do |binds_attribute|
        bind = CmsBind.new(binds_attribute)
        bind.items_attributes.each_value do |items_attribute|
          item = CmsBindItem.new(items_attribute)
          item.contents_attributes.each_value do |contents_attribute|
            content = CmsBindContent.new(contents_attribute)
            content.descriptions = '' if item.input_type == CmsBindItem.input_type_id_by_key(:code)
            item.contents << CmsBindContent.new(contents_attribute)
          end if item.contents_attributes
          bind.items << item
        end if bind.items_attributes
        @cms_page.binds << bind
      end
    end
    redirect_to(:action => 'show', :id => @cms_page.id)
  end

  # DELETE /cms_pages/1
  # DELETE /cms_pages/1.xml
  def destroy
    @cms_page = CmsPage.find(params[:id])
    CmsPage.transaction do
      @cms_page.destroy_with_titles_and_items

      respond_to do |format|
        format.html { redirect_to(cms_pages_url) }
        format.xml  { head :ok }
      end
    end
  end

  desc :auth_as => :destroy
  # DELETE /cms_pages/undo_destroy/1
  # DELETE /cms_pages/undo_destroy/1.xml
  def undo_destroy
    src_page = CmsPage.find(params[:id])
    cms_page = CmsPage.find(:first,
      :conditions => ["cms_project_id = ? and controller = ? and action = ? and delete_at_publish = ?", 
        @cms_project.id, src_page.controller, src_page.action, true])
    page_id = cms_page.id
    @cms_page = CmsPage.find(page_id)
    CmsPage.transaction do
      @cms_page.destroy_with_titles_and_items

      respond_to do |format|
        format.html { redirect_to(cms_pages_url) }
        format.xml  { head :ok }
      end
    end
  end

  desc :auth_as => :index
  def preview
    @cms_page = CmsPage.find(params[:id])
    @cms_page.deploy_to_preview(params[:locale])
    @cms_page.copy_public_files_for_preview
      
    # デフォルトテンプレートのファイルを作成
    CmsTemplate.primary_default_templates(:preferred_project_id => params[:cms_project_id])[@cms_page.terminal_key].each do |position, template|
      template.overwrite(position, :preview) unless template.nil?
    end
    redirect_to :controller => 'cms', :action => 'show', :id => @cms_page.id, :locale => params[:locale]
  end

end
